import { FieldType, ResetOpts, SetValueOpts } from "./Field";
import { ValidationObj } from "./validation";
export declare type FieldsArrayData<TField> = TField extends FieldType<infer U> ? U : never;
export declare type FieldsArrayValidator<T> = (val: T[]) => ValidationObj;
export declare type FieldsArrayOpts<TData, TField> = {
    validate?: FieldsArrayValidator<TData | null>;
    builder?: (data: TData, opts: SetValueOpts) => TField;
};
export default class FieldsArray<TField extends FieldType<FieldsArrayData<TField>>, TData = FieldsArrayData<TField>> implements FieldType<(TData | null)[]> {
    fields: TField[];
    defaultValue: (TData | null)[];
    initValue: (TData | null)[];
    validate?: FieldsArrayValidator<TData | null>;
    builder?: (data: TData, opts: SetValueOpts) => TField;
    constructor(defaultValue: TField[], { validate, builder }?: FieldsArrayOpts<TData, TField>);
    reset({ untouched, defaultValue }?: ResetOpts): void;
    markAsTouched(): void;
    markAsUntouched(): void;
    setValue(data: (TData | null)[], { interract, isInitValue }?: SetValueOpts): void;
    get(index: number): TField;
    get validation(): ValidationObj;
    get isValid(): boolean;
    get value(): (TData | null)[];
    get interacted(): boolean;
    get pristine(): boolean;
    get errorMessage(): import("./validation").ErrorMessage | undefined;
}
